@@ -69,6 +69,9 @@ class LsiModel(interfaces.TransformationABC):
         discarded, unless `keepDecomposition` is True, in which case it is stored 
         in `self.u`, `self.s` and `self.v`.
         
+        `dtype` dictates precision used for intermediate computations; the final 
+        projection will however always be of type numpy.float32.
+        
         The algorithm is adapted from:
         **M. Brand. 2006. Fast low-rank modifications of the thin singular value decomposition**
         """
@@ -110,7 +113,7 @@ class LsiModel(interfaces.TransformationABC):
         # 
         # note that neither `v` (the right singular vectors) nor `s` (the singular 
         # values) are used at all in the transformation
-        self.projection = self.u.T
+        self.projection = self.u.T.astype(numpy.float32).copy('C')
         
         if not keepDecomposition:
             # once we have the projection stored in self, discard u*s*v decomposition to free up memory
@@ -132,6 +135,7 @@ class LsiModel(interfaces.TransformationABC):
         
         vec = matutils.sparse2full(bow, self.numTerms)
         vec.shape = (self.numTerms, 1)
+        assert vec.dtype == numpy.float32 and self.projection.dtype == numpy.float32
         topicDist = self.projection * vec
         if not scaled:
             topicDist = numpy.diag(numpy.diag(1.0 / self.s)) * topicDist
@@ -237,17 +241,17 @@ class LsiModel(interfaces.TransformationABC):
 
     def printTopic(self, topicNo, topN = 10):
         """
-        Print a specified topic (0 <= `topicNo` < `self.numTopics`) in human readable format.
+        Return a specified topic (0 <= `topicNo` < `self.numTopics`) as string in human readable format.
         
         >>> lsimodel.printTopic(10, topN = 5)
-        -0.340 * "category" + 0.298 * "$M$" + 0.183 * "algebra" + -0.174 * "functor" + -0.168 * "operator"
+        '-0.340 * "category" + 0.298 * "$M$" + 0.183 * "algebra" + -0.174 * "functor" + -0.168 * "operator"'
         
         """
 #        c = numpy.asarray(self.u[:, topicNo]).flatten()
         c = numpy.asarray(self.projection[topicNo, :]).flatten()
         norm = numpy.sqrt(numpy.sum(c * c))
         most = numpy.abs(c).argsort()[::-1][:topN]
-        print ' + '.join(['%.3f * "%s"' % (1.0 * c[val] / norm, self.id2word[val]) for val in most])
+        return ' + '.join(['%.3f * "%s"' % (1.0 * c[val] / norm, self.id2word[val]) for val in most])
 #endclass LsiModel
 
 
